import { ComponentClass } from 'react';
import Taro, { Component } from '@tarojs/taro';
import { View, Image, Text } from '@tarojs/components';

import UserBoxBg from '../../images/home/img_bg@2x.png';
import ArrowIcon from '../../images/home/icon_dingdan@2x.png';
import HairDryerBg from '../../images/home/img_chuifeng_bg@2x.png';
import HairDryerArr from '../../images/home/icon_chuifeng_right@2x.png';
import AnnouncementBg from '../../images/home/img_gonggao_bg@2x.png';
import MoreIcon from '../../images/home/icon_more_right@2x.png';
import SettingIcon from '../../images/home/icon_shezhi@2x.png';
import HBeanIcon from '../../images/home/icon_chuifengdou@2x.png';
import TBeanIcon from '../../images/home/icon_tongyongdou@2x.png';
import UserHeaderM from '../../images/home/img_boy_touxiang@2x.png';
import UserHeaderF from '../../images/home/img_girl_touxiang@2x.png';

import './Home.scss';
import { connect } from '@tarojs/redux';
import { UserState } from '../../store/rootReducers/userinfo';
import { fetchBeanCount } from '../../api/bean';

type PageStateProps = {
  userinfo: UserState;
};
type PageState = {
  commBean: number;
  hairDryerBean: number;
};

interface Home {
  props: PageStateProps;
  state: PageState;
}
@connect(({ userinfo }) => ({
  userinfo,
}))
class Home extends Component {
  constructor(props) {
    super(props);
    this.state = {
      commBean: 0.0,
      hairDryerBean: 0.0,
    };
  }

  componentWillMount() {
    const { userinfo } = this.props;
    fetchBeanCount({
      id: userinfo.customerId,
      areaId: userinfo.areaId,
      customerPhone: userinfo.customerPhone,
      serviceIdList: [],
    })
      .then(res => {
        const data = res.data;
        let commBeanItem = data.find(item => item.serviceId === '1');
        let hairDryerBeanItem = data.find(item => item.serviceId === '1');
        let commBean = commBeanItem ? commBeanItem.money : 0.0;
        let hairDryerBean = hairDryerBeanItem ? hairDryerBeanItem.money : 0.0;
        this.setState({
          commBean,
          hairDryerBean,
        });
      })
      .catch(console.error);
  }

  goSetting() {
    Taro.navigateTo({
      url: '/pages/UserSetting/UserSetting',
    });
  }
  goAnn() {
    Taro.navigateTo({
      url: '/pages/Announcement/Announcement',
    });
  }

  goOrder() {
    Taro.navigateTo({
      url: '/pages/Order/OrderList/OrderList',
    });
  }

  goBarCode() {
    Taro.navigateTo({
      url: '/pages/BarCode/BarCode',
    });
  }

  render() {
    const { userinfo } = this.props;
    const { commBean, hairDryerBean } = this.state;
    return (
      <View className='Home'>
        <View className='Home-UserBox'>
          <Image
            className='Home-UserBox-Setting'
            src={SettingIcon}
            onClick={this.goSetting}
          />
          <Image className='bg' src={UserBoxBg} />
          <View className='Home-UserBox-info'>
            <View className='Home-UserBox-other'>
              <View className='Home-UserBox-name'>{userinfo.customerName}</View>
              <View className='Home-UserBox-tel'>{userinfo.customerPhone}</View>
              <View className='Home-UserBox-addr'>{userinfo.areaName}</View>
            </View>
            {userinfo.customerSex === '2' ? (
              <Image className='Home-UserBox-headimg' src={UserHeaderM} />
            ) : (
              <Image className='Home-UserBox-headimg' src={UserHeaderF} />
            )}
          </View>
          <View className='Home-UserBox-line' />
          <View className='Home-UserBox-Bean'>
            <View className='Home-UserBox-BeanItem'>
              <Image className='Home-UserBox-BeanIcon' src={HBeanIcon} />
              <Text>吹风豆：</Text>
              <Text className='Home-UserBox-BeanCount'>{hairDryerBean}</Text>
            </View>
            <View className='Home-UserBox-BeanItem'>
              <Image className='Home-UserBox-BeanIcon' src={TBeanIcon} />
              <Text>通用豆：</Text>
              <Text className='Home-UserBox-BeanCount'>{commBean}</Text>
            </View>
          </View>
          <View className='Home-UserBox-Order'>
            <Text className='Home-UserBox-Order-text'>我的订单</Text>
            <View className='Home-UserBox-Order-right' onClick={this.goOrder}>
              <Image className='Home-UserBox-Order-icon' src={ArrowIcon} />
            </View>
          </View>
        </View>
        <View className='Home-HairDryer' onClick={this.goBarCode}>
          <Image className='bg' src={HairDryerBg} />
          <View className='Home-HairDryer-shadow' />
          <View className='Home-HairDryer-text'>
            吹风
            <Image className='Home-HairDryer-arrow' src={HairDryerArr} />
          </View>
        </View>
        <View className='Home-Announcement'>
          <Image className='bg' src={AnnouncementBg} />
          <View className='Home-Announcement-title'>
            <Text>最新公告</Text>
            <View className='Home-Announcement-more' onClick={this.goAnn}>
              更多
              <Image className='more-icon' src={MoreIcon} />
            </View>
          </View>
          <View className='Home-Announcement-Content'>
            <Text>元宵节感恩回馈</Text>
            <Text className='ContentDate'>2019-02-22</Text>
          </View>
        </View>
      </View>
    );
  }
}

export default Home as ComponentClass<PageStateProps, PageState>;
