import { ComponentClass } from 'react';
import Taro, { Component, Config } from '@tarojs/taro';
import { View, Button, Text, ScrollView } from '@tarojs/components';
import { connect } from '@tarojs/redux';

import OrderItem from '../components/OrderItem/OrderItem';

import './OrderList.scss';

import { toggleOrderState } from './actions';
import { StoreState } from './store';
import { fetchAllOrder, fetchPayOrder } from '../../../api/order';
import { UserState } from '../../../store/rootReducers/userinfo';

type PageStateProps = {
  orderList: StoreState;
  userinfo: UserState;
};
type PageDispatchProps = {
  toggleOrderState: (state: String) => void;
};

type PageOwnProps = {};

type PageProps = PageStateProps & PageDispatchProps & PageOwnProps;

interface OrderList {
  props: PageProps;
}

@connect(
  ({ OrderList, userinfo }) => ({
    orderList: OrderList,
    userinfo,
  }),
  dispatch => ({
    toggleOrderState(state: String) {
      dispatch(toggleOrderState(state));
    },
  }),
)
class OrderList extends Component {
  config: Config = {
    navigationBarTitleText: '订单',
  };
  constructor(props: PageProps) {
    super(props);
  }

  componentWillMount() {
    this.getPayOrderHandle();
  }

  getPayOrderHandle(lastOrderId?: number) {
    const { userinfo } = this.props;
    fetchPayOrder(
      lastOrderId
        ? {
            customerId: userinfo.customerId,
            pageSize: 10,
            lastOrderId,
          }
        : {
            customerId: userinfo.customerId,
            pageSize: 10,
          },
    )
      .then(res => {
        console.log(res);
      })
      .catch(console.error);
  }

  getAllOrderHandle() {}

  goPayPage(data) {
    this.$preload(data);
    Taro.navigateTo({
      url: '/pages/Order/OrderPay/OrderPay',
    });
  }

  render() {
    const {
      orderList: { orderState },
      toggleOrderState,
    } = this.props;

    return (
      <View className='OrderList'>
        <View className='Tab'>
          <Text
            className={`Tab-item ${orderState === '1' ? 'active' : ''}`}
            onClick={() => toggleOrderState('1')}>
            待付款
          </Text>
          <Text
            className={`Tab-item ${orderState === 'all' ? 'active' : ''}`}
            onClick={() => toggleOrderState('all')}>
            全部
          </Text>
        </View>
        <ScrollView
          className='OrderList-Content'
          scrollY
          scrollWithAnimation
          scrollTop={0}>
          <OrderItem
            data={{ id: 1, orderState: '1' }}
            onPayHandle={this.goPayPage}
          />
          <OrderItem
            data={{ id: 1, orderState: '1' }}
            onPayHandle={this.goPayPage}
          />{' '}
          <OrderItem
            data={{ id: 1, orderState: 'all' }}
            onPayHandle={this.goPayPage}
          />
          <OrderItem
            data={{ id: 1, orderState: '1' }}
            onPayHandle={this.goPayPage}
          />
          <OrderItem
            data={{ id: 1, orderState: '1' }}
            onPayHandle={this.goPayPage}
          />
          <OrderItem
            data={{ id: 1, orderState: 'all' }}
            onPayHandle={this.goPayPage}
          />
          <OrderItem
            data={{ id: 1, orderState: '1' }}
            onPayHandle={this.goPayPage}
          />{' '}
          <OrderItem
            data={{ id: 1, orderState: 'all' }}
            onPayHandle={this.goPayPage}
          />
          <OrderItem
            data={{ id: 1, orderState: '1' }}
            onPayHandle={this.goPayPage}
          />
        </ScrollView>
      </View>
    );
  }
}

export default OrderList as ComponentClass<PageOwnProps>;
