import { ComponentClass } from 'react';
import Taro, { Component, Config } from '@tarojs/taro';
import { View, Text, Image, Button, Input } from '@tarojs/components';

import Vcode from '../../components/Vcode/Vcode';

import baseIcon from '../../images/login/icon_jibenxinxi@2x.png';
import pwdIcon from '../../images/login/icon_passworld@2x.png';
import areaIcon from '../../images/login/icon_quyu@2x.png';
import pwdHideIcon from '../../images/login/setting_invisible_icon@2x.png';
import pwdShowIcon from '../../images/login/setting_see_icon@2x.png';
import radioIcon from '../../images/login/pc_nor_icon@2x.png';
import radioCheckIcon from '../../images/login/pc_sel_icon@2x.png';
import './Register.scss';
import agreeIcon from '../../images/login/icon_zhuce_sel@2x.png';
import agreeNotIcon from '../../images/login/icon_zhuce_nor@2x.png';
import { connect } from '@tarojs/redux';
import { UserState } from '../../store/rootReducers/userinfo';
import { getVcode, fetchWxUserRegister } from '../../api/wx';

type PageStateProps = {
  userinfo: UserState;
};
type PageDispatchProps = {
  // updateUserInfo: (e: User) => void;
};

type PageState = {
  name: string;
  cellphone: string;
  vcode: string;
  pwd: string;
  checkPwd: string;
  sex: string;
  agree: boolean;
  showPwd: boolean;
  showCheckPwd: boolean;
};

type IProps = PageStateProps & PageDispatchProps;
interface Register {
  props: IProps;
  state: PageState;
}

@connect(({ userinfo }) => ({
  userinfo,
}))
class Register extends Component {
  config: Config = {
    navigationBarTitleText: '注册',
  };

  constructor(props: IProps) {
    super(props);
    this.state = {
      name: '姜雷',
      cellphone: '18108096033',
      vcode: '',
      pwd: '123456',
      checkPwd: '123456',
      sex: 'Male',
      agree: false,
      showPwd: false,
      showCheckPwd: false,
    };
  }

  setSex(value: string) {
    this.setState({
      sex: value,
    });
  }
  getVcode() {
    const { cellphone } = this.state;
    if (cellphone.length == 11) {
      // getVcode({
      //   tel: cellphone,
      // })
      //   .then(res => {
      //     console.log(res);
      //     Taro.showToast({
      //       title: res.msg,
      //       mask: true,
      //     });
      //   })
      //   .catch(console.error);
      this.refs.Vcode.countStart();
    } else {
      Taro.showToast({
        title: '输入正确的手机号',
        icon: 'none',
        mask: true,
      });
    }
  }

  validateRegisterEntity(): boolean {
    const { name, cellphone, pwd, checkPwd } = this.state;
    const {
      userinfo: { campusId },
    } = this.props;
    if (!name) {
      Taro.showToast({
        title: '请输入姓名',
        icon: 'none',
      });
      return false;
    }
    if (!cellphone || cellphone.length !== 11) {
      Taro.showToast({
        title: '请输入手机号码',
        icon: 'none',
      });
      return false;
    }
    if (!pwd) {
      Taro.showToast({
        title: '请输入密码',
        icon: 'none',
      });
      return false;
    }
    if (!checkPwd) {
      Taro.showToast({
        title: '请输入确认密码',
        icon: 'none',
      });
      return false;
    }
    if (pwd != checkPwd) {
      Taro.showToast({
        title: '请输入确认密码',
        icon: 'none',
      });
      return false;
    }
    if (!campusId) {
      Taro.showToast({
        title: '请选择所属校区',
        icon: 'none',
      });
      return false;
    }
    return true;
  }

  getRegister() {
    if (this.validateRegisterEntity()) {
      const { name, cellphone, pwd, sex } = this.state;
      const {
        userinfo: { campusId, schoolId },
      } = this.props;
      fetchWxUserRegister({
        cellphone,
        campusId,
        name,
        pwd,
        schoolId,
        sex,
      });
    }
  }

  navToCampus() {
    Taro.navigateTo({
      url: '/pages/SelectCampus/SelectCampus',
    });
  }

  togglePwdBox() {
    this.setState(({ showPwd }: PageState) => ({
      showPwd: !showPwd,
    }));
  }

  togglePwdCheckBox() {
    this.setState(({ showCheckPwd }: PageState) => ({
      showCheckPwd: !showCheckPwd,
    }));
  }

  toggleAgreeState() {
    this.setState(({ agree }: PageState) => ({
      agree: !agree,
    }));
  }

  render() {
    const {
      name,
      sex,
      showPwd,
      showCheckPwd,
      agree,
      cellphone,
      vcode,
      pwd,
      checkPwd,
    } = this.state;
    const { userinfo } = this.props;
    return (
      <View className='Register topBr'>
        <View className='registerBox'>
          <View className='registerBox-title'>
            <Image className='registerBox-icon' src={baseIcon} />
            <Text className='registerBox-text'>基本信息</Text>
          </View>
          <View className='registerBox-item'>
            <Input
              className='loginBox-input'
              placeholderClass='loginBox-placeholder'
              placeholder='输入您的姓名'
              value={name}
              onInput={({ detail: { value } }) => {
                this.setState({
                  name: value.trim(),
                });
                return value.trim();
              }}
              maxLength={20}
            />
            <View className='loginBox-input sexBox'>
              <View
                className='sexBox-item'
                onClick={() => this.setSex('Female')}>
                {sex === 'Female' ? (
                  <Image className='sexBox-icon' src={radioCheckIcon} />
                ) : (
                  <Image className='sexBox-icon' src={radioIcon} />
                )}
                <Text>女</Text>
              </View>
              <View className='sexBox-item' onClick={() => this.setSex('Male')}>
                {sex === 'Male' ? (
                  <Image className='sexBox-icon' src={radioCheckIcon} />
                ) : (
                  <Image className='sexBox-icon' src={radioIcon} />
                )}
                <Text>男</Text>
              </View>
            </View>
          </View>
          <View className='registerBox-item'>
            <Input
              className='loginBox-input'
              placeholderClass='loginBox-placeholder'
              placeholder='请输入注册的手机号码'
              type='number'
              value={cellphone}
              onInput={({ detail: { value } }) => {
                this.setState({
                  cellphone: value,
                });
                return value;
              }}
              maxLength={11}
            />
          </View>
          <View className='registerBox-item'>
            <Input
              className='loginBox-input'
              placeholderClass='loginBox-placeholder'
              placeholder='请输入验证码'
              maxLength={6}
              value={vcode}
            />
            <Vcode
              vcode-classname='registerBox-getVcode'
              ref='Vcode'
              onClickHandle={this.getVcode}
            />
          </View>
          <View className='registerBox-title'>
            <Image className='registerBox-icon' src={pwdIcon} />
            <Text className='registerBox-text'>密码设置</Text>
          </View>
          <View className='registerBox-item'>
            <Input
              className='loginBox-input'
              placeholderClass='loginBox-placeholder'
              password={!showPwd}
              placeholder='密码由6-20位组成'
              maxLength={20}
              value={pwd}
              onInput={({ detail: { value } }) => {
                this.setState({
                  pwd: value,
                });
                return value;
              }}
            />
            <Image
              className='registerBox-pwdIcon'
              src={showPwd ? pwdShowIcon : pwdHideIcon}
              onClick={this.togglePwdBox}
            />
          </View>
          <View className='registerBox-item'>
            <Input
              className='loginBox-input'
              placeholderClass='loginBox-placeholder'
              password={!showCheckPwd}
              placeholder='确认密码'
              maxLength={20}
              value={checkPwd}
              onInput={({ detail: { value } }) => {
                this.setState({
                  checkPwd: value,
                });
                return value;
              }}
            />
            <Image
              className='registerBox-pwdIcon'
              src={showCheckPwd ? pwdShowIcon : pwdHideIcon}
              onClick={this.togglePwdCheckBox}
            />
          </View>
          <View className='registerBox-title'>
            <Image className='registerBox-icon' src={areaIcon} />
            <Text className='registerBox-text'>区域信息</Text>
          </View>
          <View className='registerBox-item' onClick={this.navToCampus}>
            {userinfo.campusId ? (
              <Text>{userinfo.campusName}</Text>
            ) : (
              <Text className='noVlaue'>请填写真实区域信息</Text>
            )}
          </View>
        </View>
        <View className='registerBox-agreeBox' onClick={this.toggleAgreeState}>
          {agree ? (
            <Image className='registerBox-agreeCheck' src={agreeIcon} />
          ) : (
            <Image className='registerBox-agreeCheck' src={agreeNotIcon} />
          )}
          <Text>同意条款</Text>
          <Text className='service-deal'>《多彩校园服务协议》</Text>
        </View>
        {agree ? (
          <Button className='registerBox-button' onClick={this.getRegister}>
            确 认
          </Button>
        ) : (
          <Button className='registerBox-button' disabled>
            确 认
          </Button>
        )}
      </View>
    );
  }
}

export default Register as ComponentClass<IProps, PageState>;
